#!/bin/bash

# This script is meant to be reused from other repos that needs to run behat tests.
#
# It assumes you have already checked out ezplatform (to get access to this script) and
# moved original package into tmp_travis_folder under ezplatform folder so it is accessible
# from inside Docker images.
#
## Example use:
#
# env:
#  - COMPOSE_FILE="doc/docker/base-prod.yml:doc/docker/selenium.yml"
#
# before_install:
#  - export BRANCH_BUILD_DIR=$TRAVIS_BUILD_DIR TRAVIS_BUILD_DIR="$HOME/build/ezplatform"
#  - cd "$HOME/build"
#  - git clone --depth 1 --single-branch --branch master https://github.com/ezsystems/ezplatform.git
#  - cd ezplatform
#  - ./bin/.travis/trusty/setup_from_external_repo.sh $TRAVIS_BUILD_DIR "ezsystems/ezpublish-kernel:7.0.x-dev"
#
# script: docker-compose run -u www-data bin/behat --profile=rest --suite=fullJson --tags=~@broken

REPO_DIR=$1
META_REPO_BUILD_DIR=$2
COMPOSER_REQUIRE=${@:3}

export EZPLATFORM_BUILD_DIR=${META_REPO_BUILD_DIR}/ezplatform

if [[ -z "$COMPOSE_FILE" ]]; then
    echo 'No COMPOSE_FILE defined, exiting'
    exit 1
fi

echo "> Move '$REPO_DIR' to 'tmp_travis_folder'"
mv -r ${REPO_DIR} tmp_travis_folder

# Update docker to supported version
./bin/.travis/trusty/update_docker.sh

# Remove XDebug
phpenv config-rm xdebug.ini

echo '> Modify composer.json to point to local checkout'
composer config repositories.tmp_travis_folder path tmp_travis_folder

if [ -n "$COMPOSER_REQUIRE" ] ; then
    echo "> Requiring packages: $COMPOSER_REQUIRE"
    composer require --no-update "${COMPOSER_REQUIRE}"
fi

INSTALL_EZ_INSTALL_TYPE=${INSTALL_EZ_INSTALL_TYPE:-clean}

echo "> Start containers"
docker-compose up -d
docker-compose exec app sh -c 'chown -R www-data:www-data /var/www'
echo "> Run composer install"
docker-compose exec --user www-data app sh -c 'COMPOSER_HOME=$HOME/.composer composer install --no-suggest --no-progress --no-interaction --prefer-dist --optimize-autoloader'
echo "> Install data"
docker-compose exec --user www-data app sh -c "php /scripts/wait_for_db.php; php bin/console ezplatform:install $INSTALL_EZ_INSTALL_TYPE"

echo '> Done, ready to run tests'
